# qasi

This Python package provides a function to query a language model (like Deepseek) with candidate context and questions, and returns short, clean answers.

Try: 
pip install qasi==0.1.3
python -m spacy download en_core_web_sm
